is_isomorphic

Function is_isomorphic 

pub fn is_isomorphic(a: &Schema, b: &Schema) -> bool
True iff normalized schemas a and b are isomorphic: there is a bijection between their env record names under which the two root records (and everything reachable from them) match exactly.

Empty-schema convention. If both a and b are unsatisfiable, they are treated as isomorphic (both accept the empty language). If exactly one is empty, they are not isomorphic.