pub fn register_format(fmt: Format)Expand description
Register (or replace) a format plugin, usable everywhere a format name is
accepted, including crate::document::Doc::from_format/to_format/
check_format.
pub fn register_format(fmt: Format)Register (or replace) a format plugin, usable everywhere a format name is
accepted, including crate::document::Doc::from_format/to_format/
check_format.