pub struct Ref {
pub name: String,
}Expand description
A reference to a named record in a Schema’s environment.
Fields
name: StringThe name of the target record in the schema environment.
Implementations