pub enum ScalarKind {
String,
Integer,
Number,
Boolean,
Date,
Time,
Datetime,
}Expand description
One of the seven predefined value kinds a Scalar can hold (spec 2.2).
Variants
String
The string scalar kind (UTF-8 character string, spec 2.2).
Integer
The integer scalar kind (arbitrary-precision integer, spec 2.2).
Number
The number scalar kind (IEEE 754 double precision float or integer, spec 2.2).
Boolean
The boolean scalar kind (true or false, spec 2.2).
Date
The date scalar kind (ISO 8601 calendar date YYYY-MM-DD, spec 2.2).
Time
The time scalar kind (ISO 8601 clock time hh:mm:ss, spec 2.2).
Datetime
The datetime scalar kind (ISO 8601 combined date-time, spec 2.2).
Implementations
Sourceimpl ScalarKind
impl ScalarKind
Sourcepub const ALL: [ScalarKind; 7]
pub const ALL: [ScalarKind; 7]
All seven kinds, in the order the Python reference declares them.
Sourcepub fn as_str(&self) -> &'static str
pub fn as_str(&self) -> &'static str
Return the canonical OSD name of this scalar kind ("string", "integer", etc., spec 2.2).
Sourcepub fn parse(name: &str) -> Result<ScalarKind, SchemaError>
pub fn parse(name: &str) -> Result<ScalarKind, SchemaError>
Parse a scalar kind name, as it would appear in schema text ("date"
etc). Mirrors Scalar.__init__’s SCALAR_NAMES check.